

.swagger-section {

  .title { font-style: bold; }

  .secondary_form { display: none; }

  .main_image {
    display: block;
    margin-left: auto;
    margin-right: auto;
  }

  .oauth_body {
    margin-left: 100px;
    margin-right: 100px;
  }

  .oauth_submit {
    text-align: center;
    display: inline-block;
  }

  .authorize-wrapper {
    margin: 15px 0 10px;
  }

  .authorize-wrapper_operation {
    float: right;
  }

  .authorize__btn {
    &:hover {
      text-decoration: underline;
      cursor: pointer;
    }
  }

  .authorize__btn_operation:hover .authorize-scopes {
    display: block;
  }
  
  .authorize-scopes {
    position: absolute;
    margin-top: 20px;
    background: #FFF;
    border: 1px solid #ccc;
    border-radius: 5px;
    display: none;
    font-size: 13px;
    max-width: 300px;
    line-height: 30px;
    color: black;
    padding: 5px;

    .authorize__scope {
      text-decoration: none;
    }
  }

  .authorize__btn_operation {
    height: 18px;
    vertical-align: middle;
    display: inline-block;
    background: url(../images/explorer_icons.png) no-repeat;
  }

  .authorize__btn_operation_login {
    background-position: 0 0;
    width: 18px;
    margin-top: -6px;
    margin-left: 4px;
  }

  .authorize__btn_operation_logout {
    background-position: -30px 0;
    width: 18px;
    margin-top: -6px;
    margin-left: 4px;
  }

  #auth_container {
    color: #fff;
    display: inline-block;
    border: none;
    padding: 5px;
    width: 87px;
    height: 13px;

    .authorize__btn {
      color: #fff;
    }
  }

  .auth_container {
    padding: 0 0 10px;
    margin-bottom: 5px;
    border-bottom: solid 1px #CCC;
    font-size: 0.9em;

  .auth__title {
      color: #547f00;
      font-size: 1.2em;
    }

    .basic_auth__label {
      display: inline-block;
      width: 60px;
    }

    .auth__description {
      color: #999999;
      margin-bottom: 5px;
    }

    .auth__button {
      margin-top: 10px;
      height: 30px;
    }

    .key_auth__field {
      margin: 5px 0;
    }

    .key_auth__label {
      display: inline-block;
      width: 60px;
    }
  }

  .api-popup-dialog {
    position: absolute;
    display: none;
  }

  .api-popup-dialog-wrapper {
    z-index: 1000;
    width: 500px;
    background: #FFF;
    padding: 20px;
    border: 1px solid #ccc;
    border-radius: 5px;
    font-size: 13px;
    color: #777;
    position: fixed;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
  }

  .api-popup-dialog-shadow {
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    opacity: 0.2;
    background-color: gray;
    z-index: 900;
  }

  .api-popup-dialog .api-popup-title {
    font-size: 24px;
    padding: 10px 0;
  }

  .api-popup-dialog .api-popup-title {
    font-size: 24px;
    padding: 10px 0;
  }

  .api-popup-dialog .error-msg {
    padding-left: 5px;
    padding-bottom: 5px;
  }
  .api-popup-dialog .api-popup-content {
    max-height: 500px;
    overflow-y: auto;
  }

  .api-popup-dialog .api-popup-authbtn { height: 30px; }

  .api-popup-dialog .api-popup-cancel { height: 30px; }

  .api-popup-scopes { padding: 10px 20px; }

  .api-popup-scopes li {
    padding: 5px 0;
    line-height: 20px;
  }

  .api-popup-scopes li input {
    position: relative;
    top: 2px;
  }

  .api-popup-scopes .api-scope-desc {
    padding-left: 20px;
    font-style: italic;
  }

  .api-popup-actions { padding-top: 10px; }
}
